@@ -6,7 +6,7 @@
     
     This library is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
+    the Free Software Foundation; either version 3 of the License, or
     (at your option) any later version.
 
     This library is distributed in the hope that it will be useful,
@@ -20,7 +20,7 @@
 */
 
 /*
- * $Id: gama-g3.cpp,v 1.2 2007/01/14 15:23:20 cepek Exp $
+ * $Id: gama-g3.cpp,v 1.4 2007/06/29 17:50:31 cepek Exp $
  */
 
 #include <fstream>
@@ -28,6 +28,7 @@
 #include <gnu_gama/xml/dataparser.h>
 #include <gnu_gama/list.h>
 #include <gnu_gama/g3/g3_model.h>
+#include <gnu_gama/version.h>
 
 namespace 
 {
@@ -56,6 +57,11 @@ namespace
             ok = false;
             continue;
           }
+        if (a == "-version")
+          {
+            ok = false;
+            return 1+GNU_gama::version("gama-g3", "Ales Cepek");
+          }
         if (a == "-algorithm")
           {
             if (++i < argc)
