@@ -6,7 +6,7 @@
     
     This library is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
+    the Free Software Foundation; either version 3 of the License, or
     (at your option) any later version.
 
     This library is distributed in the hope that it will be useful,
@@ -20,7 +20,7 @@
 */
 
 /*
- *  $Id: adj.h,v 1.3 2007/01/14 15:23:20 cepek Exp $
+ *  $Id: adj.h,v 1.6 2007/06/26 15:04:09 cepek Exp $
  */
 
 #include <matvec/covmat.h>
@@ -49,7 +49,7 @@ namespace GNU_gama {
     
     enum algorithm {envelope, gso, svd, cholesky};
     
-    Adj () : data(0), algorithm_(gso), minx_dim(0), minx(0) { init(0); }
+    Adj () : data(0), algorithm_(envelope), minx_dim(0), minx(0) { init(0); }
     virtual ~Adj();
     
     int n_obs() const { return n_obs_; }
@@ -117,8 +117,6 @@ namespace GNU_gama {
     void set_rhs (Vec          <>   p) {               prhs  = p; }
     void set_minx(IntegerList  <> * p) { delete pminx; pminx = p; } 
 
-    void swap(AdjInputData *);
-
     /* Sparse project equations for uncorrelated observations. *
      * Defined here only for backward data compatibility       */
     void read_gama_local_old_format(std::istream&);
@@ -133,6 +131,7 @@ namespace GNU_gama {
     Vec          <>   prhs;
     IntegerList  <> * pminx;
 
+    void swap(AdjInputData *);
   };
   
 }  // namespace GNU_gama
