@@ -6,7 +6,7 @@
     
     This library is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
+    the Free Software Foundation; either version 3 of the License, or
     (at your option) any later version.
 
     This library is distributed in the hope that it will be useful,
@@ -20,7 +20,7 @@
 */
 
 /*
- *  $Id: dataparser.cpp,v 1.2 2006/04/23 15:36:21 cepek Exp $
+ *  $Id: dataparser.cpp,v 1.12 2007/06/26 15:04:11 cepek Exp $
  */
 
 
@@ -47,6 +47,7 @@ DataParser::~DataParser()
 {
   close_adj();
   close_g3();
+  close_g3adj();
 
   delete adj_sparse_mat;
   delete adj_block_diagonal;
@@ -56,8 +57,9 @@ DataParser::~DataParser()
 
 DataParser::DataParser(List<DataObject::Base*>& obs) : objects(obs)
 {
-  adj = 0;
-  g3  = 0;
+  adj   = 0;
+  g3    = 0;
+  g3adj = 0;
 
   adj_sparse_mat = 0;
   adj_block_diagonal = 0;
@@ -93,6 +95,10 @@ DataParser::DataParser(List<DataObject::Base*>& obs) : objects(obs)
 
   init_g3(); 
 
+  // .....  <g3-adjustment-reults>  ..................................
+
+  init_g3adj(); 
+
   // .....  <text>  ..................................................
  
   init(s_gama_data, t_text,
@@ -148,40 +154,90 @@ DataParser::data_tag DataParser::tag(const char* c)
     {
     case 'a':
       if (!strcmp(c, "a"                         )) return t_a;
+      if (!strcmp(c, "algorithm"                 )) return t_algorithm;
       if (!strcmp(c, "angle"                     )) return t_angle;
       if (!strcmp(c, "adj-input-data"            )) return t_adj_input_data;
+      if (!strcmp(c, "adjusted"                  )) return t_adjusted;
+      if (!strcmp(c, "adjusted-observations"     )) return t_adj_observations;
+      if (!strcmp(c, "adjustment-results"        )) return t_adj_results;
+      if (!strcmp(c, "adjustment-statistics"     )) return t_adj_statistics;
       if (!strcmp(c, "angular-units-degrees"     )) return t_ang_degrees;
       if (!strcmp(c, "angular-units-gons"        )) return t_ang_gons;
       if (!strcmp(c, "apriori-standard-deviation")) return t_apriori_sd;
+      if (!strcmp(c, "apriori-variance"          )) return t_apriori_var;
+      if (!strcmp(c, "aposteriori-variance"      )) return t_aposteriori_var;
       if (!strcmp(c, "array"                     )) return t_array;
       if (!strcmp(c, "azimuth"                   )) return t_azimuth;
       break;                                     
     case 'b':                                    
       if (!strcmp(c, "b"                         )) return t_b;
+      if (!strcmp(c, "b-adjusted"                )) return t_b_adjusted;
+      if (!strcmp(c, "b-correction"              )) return t_b_correction;
+      if (!strcmp(c, "b-given"                   )) return t_b_given;
       if (!strcmp(c, "band"                      )) return t_band;
       if (!strcmp(c, "block-diagonal"            )) return t_block_diagonal;
       if (!strcmp(c, "blocks"                    )) return t_blocks;
       if (!strcmp(c, "block"                     )) return t_block;
       break;                                     
     case 'c' :                                   
+      if (!strcmp(c, "caption"                   )) return t_caption;
+      if (!strcmp(c, "cee"                       )) return t_cee;
+      if (!strcmp(c, "ceu"                       )) return t_ceu;
+      if (!strcmp(c, "cnn"                       )) return t_cnn;
+      if (!strcmp(c, "cne"                       )) return t_cne;
+      if (!strcmp(c, "cnu"                       )) return t_cnu;
       if (!strcmp(c, "confidence-level"          )) return t_conf_level;
       if (!strcmp(c, "cols"                      )) return t_cols;
       if (!strcmp(c, "constants"                 )) return t_constants;
       if (!strcmp(c, "constr"                    )) return t_constr;
+      // (!strcmp(c, "constr-height"             )) return t_constr_height;
+      // (!strcmp(c, "constr-position"           )) return t_constr_position;
       if (!strcmp(c, "cov-mat"                   )) return t_covmat;
+      if (!strcmp(c, "cuu"                       )) return t_cuu;
+      if (!strcmp(c, "cxx"                       )) return t_cxx;
+      if (!strcmp(c, "cxy"                       )) return t_cxy;
+      if (!strcmp(c, "cxz"                       )) return t_cxz;
+      if (!strcmp(c, "cyy"                       )) return t_cyy;
+      if (!strcmp(c, "cyz"                       )) return t_cyz;
+      if (!strcmp(c, "czz"                       )) return t_czz;
       break;                                     
     case 'd' :                                   
       if (!strcmp(c, "db"                        )) return t_db;
+      if (!strcmp(c, "de"                        )) return t_de;
+      if (!strcmp(c, "defect"                    )) return t_defect;
+      if (!strcmp(c, "design-matrix-graph"       )) return t_design_m_graph;
       if (!strcmp(c, "dim"                       )) return t_dim;
       if (!strcmp(c, "distance"                  )) return t_dist;
       if (!strcmp(c, "dl"                        )) return t_dl;
+      if (!strcmp(c, "dn"                        )) return t_dn;
+      if (!strcmp(c, "du"                        )) return t_du;
       if (!strcmp(c, "dx"                        )) return t_dx;
+      if (!strcmp(c, "dx-observed"               )) return t_dx_observed;
+      if (!strcmp(c, "dx-residual"               )) return t_dx_residual;
+      if (!strcmp(c, "dx-adjusted"               )) return t_dx_adjusted;
+      if (!strcmp(c, "dx-stdev-obs"              )) return t_dx_stdev_obs;
+      if (!strcmp(c, "dx-stdev-adj"              )) return t_dx_stdev_adj;
       if (!strcmp(c, "dy"                        )) return t_dy;
+      if (!strcmp(c, "dy-observed"               )) return t_dy_observed;
+      if (!strcmp(c, "dy-residual"               )) return t_dy_residual;
+      if (!strcmp(c, "dy-adjusted"               )) return t_dy_adjusted;
+      if (!strcmp(c, "dy-stdev-obs"              )) return t_dy_stdev_obs;
+      if (!strcmp(c, "dy-stdev-adj"              )) return t_dy_stdev_adj;
       if (!strcmp(c, "dz"                        )) return t_dz;
+      if (!strcmp(c, "dz-observed"               )) return t_dz_observed;
+      if (!strcmp(c, "dz-residual"               )) return t_dz_residual;
+      if (!strcmp(c, "dz-adjusted"               )) return t_dz_adjusted;
+      if (!strcmp(c, "dz-stdev-obs"              )) return t_dz_stdev_obs;
+      if (!strcmp(c, "dz-stdev-adj"              )) return t_dz_stdev_adj;
       break;                                     
     case 'e':                                    
       if (!strcmp(c, "e"                         )) return t_e;
+      if (!strcmp(c, "e-fixed"                   )) return t_e_fixed;
+      if (!strcmp(c, "e-free"                    )) return t_e_free;
+      if (!strcmp(c, "e-constr"                  )) return t_e_constr;
+      if (!strcmp(c, "e-unused"                  )) return t_e_unused;
       if (!strcmp(c, "ellipsoid"                 )) return t_ellipsoid;
+      if (!strcmp(c, "equations"                 )) return t_equations;
       break;                                     
     case 'f' :                                   
       if (!strcmp(c, "fixed"                     )) return t_fixed;
@@ -191,36 +247,56 @@ DataParser::data_tag DataParser::tag(const char* c)
       if (!strcmp(c, "free"                      )) return t_free;
       break;                                     
     case 'g' :                                   
+      if (!strcmp(c, "g3-adjustment-results"     )) return t_g3_adj_results;
       if (!strcmp(c, "g3-model"                  )) return t_g3_model;
       if (!strcmp(c, "geoid"                     )) return t_geoid;
       if (!strcmp(c, "gnu-gama-data"             )) return t_gama_data;
       break;                                     
     case 'h':                                    
       if (!strcmp(c, "h"                         )) return t_h;
+      if (!strcmp(c, "h-adjusted"                )) return t_h_adjusted;
+      if (!strcmp(c, "h-correction"              )) return t_h_correction;
+      if (!strcmp(c, "h-given"                   )) return t_h_given;
       if (!strcmp(c, "hdiff"                     )) return t_hdiff;
       if (!strcmp(c, "height"                    )) return t_height;
+      if (!strcmp(c, "hobs"                      )) return t_hobs;
       break;                                     
     case 'i':                                    
       if (!strcmp(c, "id"                        )) return t_id;
+      if (!strcmp(c, "ind"                       )) return t_ind;
       if (!strcmp(c, "int"                       )) return t_int;
       if (!strcmp(c, "inv-f"                     )) return t_inv_f;
       break;                                     
     case 'l':                                    
       if (!strcmp(c, "l"                         )) return t_l;
+      if (!strcmp(c, "l-adjusted"                )) return t_l_adjusted;
+      if (!strcmp(c, "l-correction"              )) return t_l_correction;
+      if (!strcmp(c, "l-given"                   )) return t_l_given;
       if (!strcmp(c, "left"                      )) return t_left;
       if (!strcmp(c, "left-dh"                   )) return t_left_dh;
       break;                                     
     case 'n':                                    
       if (!strcmp(c, "n"                         )) return t_n;
+      if (!strcmp(c, "n-fixed"                   )) return t_n_fixed;
+      if (!strcmp(c, "n-free"                    )) return t_n_free;
+      if (!strcmp(c, "n-constr"                  )) return t_n_constr;
+      if (!strcmp(c, "n-unused"                  )) return t_n_unused;
       if (!strcmp(c, "nonz"                      )) return t_nonz;
       break;                                     
     case 'o':                                    
       if (!strcmp(c, "obs"                       )) return t_obs;
+      if (!strcmp(c, "observed"                  )) return t_observed;
       break;                                     
     case 'p':                                    
+      if (!strcmp(c, "parameters"                )) return t_parameters;
       if (!strcmp(c, "point"                     )) return t_point;
       break;                                     
     case 'r':                                    
+      if (!strcmp(c, "reason"                    )) return t_reason;
+      if (!strcmp(c, "redundancy"                )) return t_redundancy;
+      if (!strcmp(c, "rejected"                  )) return t_rejected;
+      if (!strcmp(c, "rejected-observations"     )) return t_rejected_obs;
+      if (!strcmp(c, "residual"                  )) return t_residual;
       if (!strcmp(c, "right"                     )) return t_right;
       if (!strcmp(c, "right-dh"                  )) return t_right_dh;
       if (!strcmp(c, "row"                       )) return t_row;
@@ -228,7 +304,10 @@ DataParser::data_tag DataParser::tag(const char* c)
       break;                                     
     case 's':                                    
       if (!strcmp(c, "stdev"                     )) return t_stdev;
+      if (!strcmp(c, "stdev-obs"                 )) return t_stdev_obs;
+      if (!strcmp(c, "stdev-adj"                 )) return t_stdev_adj;
       if (!strcmp(c, "sparse-mat"                )) return t_sparse_mat;
+      if (!strcmp(c, "sum-of-squares"            )) return t_sum_of_squares;
       break;                                     
     case 't' :                                   
       if (!strcmp(c, "text"                      )) return t_text;
@@ -237,11 +316,16 @@ DataParser::data_tag DataParser::tag(const char* c)
       break;                                     
     case 'u' :                                   
       if (!strcmp(c, "u"                         )) return t_u;
+      if (!strcmp(c, "u-fixed"                   )) return t_u_fixed;
+      if (!strcmp(c, "u-free"                    )) return t_u_free;
+      if (!strcmp(c, "u-constr"                  )) return t_u_constr;
+      if (!strcmp(c, "u-unused"                  )) return t_u_unused;
       if (!strcmp(c, "unused"                    )) return t_unused;
       break;                                     
     case 'v' :                                   
       if (!strcmp(c, "val"                       )) return t_val;
       if (!strcmp(c, "variance"                  )) return t_variance;
+      if (!strcmp(c, "variance-factor-used"      )) return t_variance_factor;
       if (!strcmp(c, "vector"                    )) return t_vector;
       break;                                     
     case 'w' :                                   
@@ -249,13 +333,37 @@ DataParser::data_tag DataParser::tag(const char* c)
       break;                                     
     case 'x' :                                   
       if (!strcmp(c, "x"                         )) return t_x;
+      if (!strcmp(c, "x-adjusted"                )) return t_x_adjusted;
+      if (!strcmp(c, "x-correction"              )) return t_x_correction;
+      if (!strcmp(c, "x-given"                   )) return t_x_given;
+      if (!strcmp(c, "x-observed"                )) return t_x_observed;
+      if (!strcmp(c, "x-residual"                )) return t_x_residual;
+      if (!strcmp(c, "x-adjusted"                )) return t_x_adjusted;
+      if (!strcmp(c, "x-stdev-obs"               )) return t_x_stdev_obs;
+      if (!strcmp(c, "x-stdev-adj"               )) return t_x_stdev_adj;
       if (!strcmp(c, "xyz"                       )) return t_xyz;
       break;                                     
     case 'y' :                                   
       if (!strcmp(c, "y"                         )) return t_y;
+      if (!strcmp(c, "y-adjusted"                )) return t_y_adjusted;
+      if (!strcmp(c, "y-correction"              )) return t_y_correction;
+      if (!strcmp(c, "y-given"                   )) return t_y_given;
+      if (!strcmp(c, "y-observed"                )) return t_y_observed;
+      if (!strcmp(c, "y-residual"                )) return t_y_residual;
+      if (!strcmp(c, "y-adjusted"                )) return t_y_adjusted;
+      if (!strcmp(c, "y-stdev-obs"               )) return t_y_stdev_obs;
+      if (!strcmp(c, "y-stdev-adj"               )) return t_y_stdev_adj;
       break;                                     
     case 'z' :                                   
       if (!strcmp(c, "z"                         )) return t_z;
+      if (!strcmp(c, "z-adjusted"                )) return t_z_adjusted;
+      if (!strcmp(c, "z-correction"              )) return t_z_correction;
+      if (!strcmp(c, "z-given"                   )) return t_z_given;
+      if (!strcmp(c, "z-observed"                )) return t_z_observed;
+      if (!strcmp(c, "z-residual"                )) return t_z_residual;
+      if (!strcmp(c, "z-adjusted"                )) return t_z_adjusted;
+      if (!strcmp(c, "z-stdev-obs"               )) return t_z_stdev_obs;
+      if (!strcmp(c, "z-stdev-adj"               )) return t_z_stdev_adj;
       if (!strcmp(c, "zenith"                    )) return t_zenith;
       break;
     default:
